@@ -515,7 +515,7 @@ class Client(BaseClient):
     def add_and_tag_files(
         self, paths_and_files: List[_PathOrFileType], tags: List[str], services: Optional[List[str]] = None,
     ) -> List[_AddFileResultType]:
-        services = ["my tags"] if services is None else ["my tags"]
+        services = ["my tags"] if services is None else services
 
         results = []
         hashes = set()
